=======
Readers
=======

.. currentmodule:: pulsarbat.readers

.. autosummary::
   :toctree: generated/
   :template: signal_class.rst

    BaseReader
    BasebandReader
    GUPPIRawReader
    DADAStokesReader
